@@ -9,6 +9,7 @@
 
 from docx2python import docx2python
 
+
 def test() -> None:
     """Just making sure the import works."""
-    docx2python('resources/example.docx')
\ No newline at end of file
+    docx2python("resources/example.docx")
