@@ -20,7 +20,6 @@ from docx2python.iterators import (
     iter_paragraphs,
     iter_rows,
     iter_tables,
-    copy_table,
     get_html_map,
 )
 
@@ -136,14 +135,6 @@ class TestEnumerators:
         ]
 
 
-class TestCopyTable:
-    """Test iterators.copy_table"""
-
-    def test_copy_table(self) -> None:
-        """Copy structure. Convert any input sequence to list."""
-        assert copy_table((((("text",),),),)) == [[[["text"]]]]
-
-
 class TestGetText:
     """Test iterators.get_text"""
 
